/*
    FreeRTOS V9.0.0 - Copyright (C) 2016 Real Time Engineers Ltd.
    All rights reserved

    VISIT http://www.FreeRTOS.org TO ENSURE YOU ARE USING THE LATEST VERSION.

    This file is part of the FreeRTOS distribution.

    FreeRTOS is free software; you can redistribute it and/or modify it under
    the terms of the GNU General Public License (version 2) as published by the
    Free Software Foundation >>>> AND MODIFIED BY <<<< the FreeRTOS exception.

    ***************************************************************************
    >>!   NOTE: The modification to the GPL is included to allow you to     !<<
    >>!   distribute a combined work that includes FreeRTOS without being   !<<
    >>!   obliged to provide the source code for proprietary components     !<<
    >>!   outside of the FreeRTOS kernel.                                   !<<
    ***************************************************************************

    FreeRTOS is distributed in the hope that it will be useful, but WITHOUT ANY
    WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    FOR A PARTICULAR PURPOSE.  Full license text is available on the following
    link: http://www.freertos.org/a00114.html

    ***************************************************************************
     *                                                                       *
     *    FreeRTOS provides completely free yet professionally developed,    *
     *    robust, strictly quality controlled, supported, and cross          *
     *    platform software that is more than just the market leader, it     *
     *    is the industry's de facto standard.                               *
     *                                                                       *
     *    Help yourself get started quickly while simultaneously helping     *
     *    to support the FreeRTOS project by purchasing a FreeRTOS           *
     *    tutorial book, reference manual, or both:                          *
     *    http://www.FreeRTOS.org/Documentation                              *
     *                                                                       *
    ***************************************************************************

    http://www.FreeRTOS.org/FAQHelp.html - Having a problem?  Start by reading
    the FAQ page "My application does not run, what could be wrong?".  Have you
    defined configASSERT()?

    http://www.FreeRTOS.org/support - In return for receiving this top quality
    embedded software for free we request you assist our global community by
    participating in the support forum.

    http://www.FreeRTOS.org/training - Investing in training allows your team to
    be as productive as possible as early as possible.  Now you can receive
    FreeRTOS training directly from Richard Barry, CEO of Real Time Engineers
    Ltd, and the world's leading authority on the world's leading RTOS.

    http://www.FreeRTOS.org/plus - A selection of FreeRTOS ecosystem products,
    including FreeRTOS+Trace - an indispensable productivity tool, a DOS
    compatible FAT file system, and our tiny thread aware UDP/IP stack.

    http://www.FreeRTOS.org/labs - Where new FreeRTOS products go to incubate.
    Come and try FreeRTOS+TCP, our new open source TCP/IP stack for FreeRTOS.

    http://www.OpenRTOS.com - Real Time Engineers ltd. license FreeRTOS to High
    Integrity Systems ltd. to sell under the OpenRTOS brand.  Low cost OpenRTOS
    licenses offer ticketed support, indemnification and commercial middleware.

    http://www.SafeRTOS.com - High Integrity Systems also provide a safety
    engineered and independently SIL3 certified version for use in safety and
    mission critical applications that require provable dependability.

    1 tab == 4 spaces!
*/

#ifndef FREERTOS_CONFIG_H
#define FREERTOS_CONFIG_H

/*-----------------------------------------------------------
 * Application specific definitions.
 *
 * These definitions should be adjusted for your particular hardware and
 * application requirements.
 *
 * THESE PARAMETERS ARE DESCRIBED WITHIN THE 'CONFIGURATION' SECTION OF THE
 * FreeRTOS API DOCUMENTATION AVAILABLE ON THE FreeRTOS.org WEB SITE.
 *
 * See http://www.freertos.org/a00110.html.
 *----------------------------------------------------------*/

#define configUSE_PREEMPTION                    1
#define configUSE_IDLE_HOOK                     0
#define configUSE_TICK_HOOK                     0
#define configCPU_CLOCK_HZ                      ( ( unsigned long ) 80000000 )
#define configTICK_RATE_HZ                      ( ( TickType_t ) 1000 )
#define configMINIMAL_STACK_SIZE                ( ( unsigned short ) 70 )
#if defined(CONFIG_ENABLE_OV_DATA_DUMPING) || defined(CONFIG_ENABLE_STREAM_DUMPING) || defined(CONFIG_ENABLE_ACCELEROMETER_DUMPING) || defined(CONFIG_ENABLE_GLANCE_DUMPING) || defined(CONFIG_ENABLE_PCU_DUMPING)
#if defined(CONFIG_WIRE_POWERED)
#define configTOTAL_HEAP_SIZE                   ( ( size_t ) ( 31944) )
#else
#define configTOTAL_HEAP_SIZE                   ( ( size_t ) ( 32576) )
#endif // CONFIG_WIRE_POWERED
#elif defined(CONFIG_WIRE_POWERED)
#if defined(CONFIG_MANUFACTURING_APP)
#define configTOTAL_HEAP_SIZE                   ( ( size_t ) ( 31176) )
#else
#define configTOTAL_HEAP_SIZE                   ( ( size_t ) ( 30712) )
#endif // CONFIG_MANUFACTURING_APP
#else
#define configTOTAL_HEAP_SIZE                   ( ( size_t ) ( 30864 + 96) )
#endif // defined(CONFIG_WIRE_POWERED)
#define configMAX_TASK_NAME_LEN                 ( 12 )
#define configUSE_TRACE_FACILITY                1
#define configUSE_16_BIT_TICKS                  0
#define configIDLE_SHOULD_YIELD                 0
#define configUSE_CO_ROUTINES                   0
#define configUSE_MUTEXES                       1
#define configUSE_RECURSIVE_MUTEXES             1
#define configCHECK_FOR_STACK_OVERFLOW          2
#define configUSE_QUEUE_SETS                    1
#define configUSE_COUNTING_SEMAPHORES           1
#define configENABLE_HEAP_PROTECTOR             1

#define configMAX_PRIORITIES                    ( 15UL )
#define configMAX_CO_ROUTINE_PRIORITIES         ( 2 )
#define configQUEUE_REGISTRY_SIZE               10

/* Dimensions a buffer that can be used by the FreeRTOS+CLI command
interpreter.  Set this value to 1 to save RAM if FreeRTOS+CLI does not supply
the output butter.  See the FreeRTOS+CLI documentation for more information:
http://www.FreeRTOS.org/FreeRTOS-Plus/FreeRTOS_Plus_CLI/ */
#define configCOMMAND_INT_MAX_OUTPUT_SIZE       256

#ifdef TICKLESS_PM

#define configUSE_TICKLESS_IDLE                 0

/* First define the portSUPPRESS_TICKS_AND_SLEEP() macro.  The parameter is the
time, in ticks, until the kernel next needs to execute. */
#define portSUPPRESS_TICKS_AND_SLEEP( xIdleTime ) vApplicationTicklessIdleHook( xIdleTime )

#define configEXPECTED_IDLE_TIME_BEFORE_SLEEP   5
#endif


/* Timer related defines. */
#define configUSE_TIMERS                        1
#define configTIMER_TASK_PRIORITY               11
#define configTIMER_QUEUE_LENGTH                21
#define configTIMER_TASK_STACK_DEPTH            ( configMINIMAL_STACK_SIZE * 2 )

#if defined(FREERTOS_ASSERTS)
#if !defined(__IAR_SYSTEMS_ASM__)
void vAssertCalled( const char *pcFile, unsigned long ulLine );
#endif /* __IAR_SYSTEMS_ASM__ */

#define configASSERT( x ) do { if ((x) == 0) { vAssertCalled(NULL, 0); } } while (0)
#else /* defined(FREERTOS_ASSERTS) */
#define configASSERT( x ) (void)(x)
#endif /* defined(FREERTOS_ASSERTS) */

#define configUSE_MALLOC_FAILED_HOOK            1
#define configENABLE_BACKWARD_COMPATIBILITY     0

/* Set the following definitions to 1 to include the API function, or zero
to exclude the API function. */

/* Need for pthread */
#define configUSE_APPLICATION_TASK_TAG          1

#define INCLUDE_vTaskPrioritySet                1
#define INCLUDE_uxTaskPriorityGet               1
#define INCLUDE_vTaskDelete                     1
#define INCLUDE_vTaskCleanUpResources           1
#define INCLUDE_vTaskSuspend                    1
#define INCLUDE_vTaskDelayUntil                 1
#define INCLUDE_vTaskDelay                      1
#define INCLUDE_uxTaskGetStackHighWaterMark     1
#define INCLUDE_xTaskGetSchedulerState          1
#define INCLUDE_xTimerGetTimerDaemonTaskHandle  0
#define INCLUDE_xTaskGetIdleTaskHandle          1
#define INCLUDE_pcTaskGetTaskName               1
#define INCLUDE_eTaskGetState                   1
#define INCLUDE_xSemaphoreGetMutexHolder        0
#define INCLUDE_xTaskGetHandle                  1

/*
 *  Priority 7, or 255 as only the top three bits are implemented.
 *  This is the lowest priority.
 */
#define configKERNEL_INTERRUPT_PRIORITY         ( 7 << 5 )

/*
 *  !!!! configMAX_SYSCALL_INTERRUPT_PRIORITY must not be set to zero !!!!
 *  See http://www.FreeRTOS.org/RTOS-Cortex-M3-M4.html.
 */
/* Priority 1, or 32 as only the top three bits are implemented. */
#define configMAX_SYSCALL_INTERRUPT_PRIORITY    ( 1 << 5 )

/* Use the Cortex-M3 optimised task selection rather than the generic C code
version. */
#define configUSE_PORT_OPTIMISED_TASK_SELECTION 1

#define configPOSIX_STACK_SIZE          ( ( unsigned short ) 512 )

#endif /* FREERTOS_CONFIG_H */
